##  Avoiding Duplicates When Importing IT Components
Duplication is prevented based on the display name of the fact sheet. When importing IT components via an Excel spreadsheet, any items that match the display name of an existing fact sheet are automatically skipped to prevent duplication. An error message is displayed in the import file next to the affected items.
![Error message indicating there is already an IT component of the same name in the Inventory](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio523b0543456f4e75b2495a7c4b8306c6_LowRes.png)
Error message indicating there is already an IT component of the same name in the Inventory
When importing IT components from inventory builder or SAP discovery, Self-built software discovery, and ServiceNow, duplicates are automatically avoided based on the display name of the fact sheet. The inventory builder or SAP discovery inboxes also visually differentiate the existing ones from the new ones - solid icons indicate existing fact sheets, while outlined (empty) icons represent new ones.
**Tip**
In the reference catalog configuration, select the Name and Release fields to sync from the reference catalog to IT component fact sheets. It ensures naming consistency across fact sheets and helps avoid duplicates when multiple import methods are used. For a detailed guide, see [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.").
